@@ -20,7 +20,7 @@ class TaskJuggler
     def initialize(resource, scenarioIdx, attributes)
       super
 
-      # Scoreboard may be nil, a Task, or a bit vector encoded as a Fixnum
+      # Scoreboard may be nil, a Task, or a bit vector encoded as an Integer
       # nil:        Value has not been determined yet.
       # Task:       A reference to a Task object
       # Bit 0:      Reserved
@@ -279,6 +279,23 @@ class TaskJuggler
       query.string = query.scaleLoad(val)
     end
 
+    # Compute a list of the annual leave days within the period specified by
+    # the _query_. The result is a list of dates and how much of that day was
+    # taken.
+    def query_annualleavelist(query)
+      iv_list = collectLeaveIntervals(Interval.new(query.start, query.end), :annual)
+      iv_list.map! do |iv|
+        # The interval is at most one working day. We list the date of that
+        # day.
+        day = iv.start.strftime(@project['timeFormat'])
+        # And how much of the working day was taken. A full working day is
+        # 1.0, a half working day 0.5.
+        days = (iv.end - iv.start) / (60 * 60 * @project['dailyworkinghours'])
+        "#{day} (#{'%.1f' % days})"
+      end
+      query.assignList(iv_list)
+    end
+
     def query_annualleavebalance(query)
       if @property.leaf?
         leave = getLeave(query.startIdx, query.endIdx, :annual)
@@ -685,7 +702,22 @@ class TaskJuggler
       initScoreboard if @scoreboard.nil?
 
       @scoreboard.collectIntervals(iv, minDuration) do |val|
-        val.is_a?(Fixnum) && (val & 0x3E) != 0
+        val.is_a?(Integer) && (val & 0x3E) != 0
+      end
+    end
+
+    # Return a list of scoreboard intervals that are at least _minDuration_ long
+    # and only contain leave slots of the given type. The result is an Array of
+    # [ start, end ] TjTime values.
+    def collectLeaveIntervals(iv, type)
+      # Time-off intervals are only useful for leaf resources. Group resources
+      # would just default to the global working hours.
+      return [] unless @property.leaf?
+
+      initScoreboard if @scoreboard.nil?
+
+      @scoreboard.collectIntervals(iv, 60 * 60) do |val|
+        val.is_a?(Integer) && (val & 0x3E) == (Leave::Types[type] << 2)
       end
     end
 
@@ -723,7 +755,7 @@ class TaskJuggler
     # leave.
     def getLeaveSlots(startIdx, endIdx, type)
       countSlots(startIdx, endIdx) do |val|
-        val.is_a?(Fixnum) && (val & 0x3E) == (Leave::Types[type] << 2)
+        val.is_a?(Integer) && (val & 0x3E) == (Leave::Types[type] << 2)
       end
     end
 
@@ -739,7 +771,7 @@ class TaskJuggler
     def getTimeOffSlots(startIdx, endIdx)
       countSlots(startIdx, endIdx) do |val|
         # Bit 1 needs to be unset and the leave bits must not be 0.
-        val.is_a?(Fixnum) && (val & 0x2) == 0 && (val & 0x3C) != 0
+        val.is_a?(Integer) && (val & 0x2) == 0 && (val & 0x3C) != 0
       end
     end
 
@@ -900,7 +932,7 @@ class TaskJuggler
       initScoreboard unless @scoreboard
 
       val = @scoreboard[sbIdx]
-      return true unless val.is_a?(Fixnum)
+      return true unless val.is_a?(Integer)
 
       leave_type = (val >> 2) & 0xF
       leave_type < Leave::Types[:unemployed]
