@@ -3,7 +3,7 @@
 #
 # = Shift.rb -- The TaskJuggler III Project Management Software
 #
-# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
+# Copyright (c) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2019
 #               by Chris Schlaeger <cs@taskjuggler.org>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@ class TaskJuggler
     # provided by the class ShiftScenario. In case we can't find a
     # function called for the Shift class we try to find it in
     # ShiftScenario.
-    def method_missing(func, scenarioIdx, *args)
+    def method_missing(func, scenarioIdx = 0, *args)
       @data[scenarioIdx].method(func).call(*args)
     end
 
